# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkStatisticsLabelObjectPython
else:
    import _itkStatisticsLabelObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkIndexPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkOffsetPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.itkShapeLabelObjectPython
import itk.itkLabelObjectPython
import itk.itkLabelObjectLinePython
import itk.itkImageRegionPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkArray2DPython
import itk.itkVariableLengthVectorPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkHistogramPython
import itk.itkSamplePython
class mapitkStatisticsLabelObjectUL2(collections.abc.MutableMapping if _swig_python_version_info >= (3, 3) else collections.MutableMapping):
    r"""Proxy of C++ std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::size_type"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___len__(self)
    def __iter__(self):
        return self.key_iterator()
    def iterkeys(self):
        return self.key_iterator()
    def itervalues(self):
        return self.value_iterator()
    def iteritems(self):
        return self.iterator()

    def __getitem__(self, key):
        r"""
        __getitem__(self, key) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::mapped_type const &

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___getitem__(self, key)

    def __delitem__(self, key):
        r"""
        __delitem__(self, key)

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___delitem__(self, key)

    def has_key(self, key):
        r"""
        has_key(self, key) -> bool

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_has_key(self, key)

    def keys(self):
        r"""keys(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_keys(self)

    def values(self):
        r"""values(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_values(self)

    def items(self):
        r"""items(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_items(self)

    def __contains__(self, key):
        r"""
        __contains__(self, key) -> bool

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___contains__(self, key)

    def key_iterator(self):
        r"""key_iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_key_iterator(self)

    def value_iterator(self):
        r"""value_iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_value_iterator(self)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, key)

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        __setitem__(self, key, x)

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &
        x: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::mapped_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2___setitem__(self, *args)

    def asdict(self):
        r"""asdict(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_asdict(self)

    def __init__(self, *args):
        r"""
        __init__(self, other) -> mapitkStatisticsLabelObjectUL2

        Parameters
        ----------
        other: std::less< unsigned long > const &

        __init__(self) -> mapitkStatisticsLabelObjectUL2
        __init__(self, other) -> mapitkStatisticsLabelObjectUL2

        Parameters
        ----------
        other: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > > const &

        """
        _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_swiginit(self, _itkStatisticsLabelObjectPython.new_mapitkStatisticsLabelObjectUL2(*args))

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_empty(self)

    def size(self):
        r"""size(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::size_type"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > > &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_begin(self)

    def end(self):
        r"""end(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::allocator_type"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_get_allocator(self)

    def count(self, x):
        r"""
        count(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::size_type

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_count(self, x)

    def erase(self, *args):
        r"""
        erase(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::size_type

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        erase(self, position)

        Parameters
        ----------
        position: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator

        erase(self, first, last)

        Parameters
        ----------
        first: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator
        last: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_erase(self, *args)

    def find(self, x):
        r"""
        find(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_find(self, x)

    def lower_bound(self, x):
        r"""
        lower_bound(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_lower_bound(self, x)

    def upper_bound(self, x):
        r"""
        upper_bound(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::iterator

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL2_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_upper_bound(self, x)
    __swig_destroy__ = _itkStatisticsLabelObjectPython.delete_mapitkStatisticsLabelObjectUL2

# Register mapitkStatisticsLabelObjectUL2 in _itkStatisticsLabelObjectPython:
_itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL2_swigregister(mapitkStatisticsLabelObjectUL2)
class vectoritkStatisticsLabelObjectUL2(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::vector< itkStatisticsLabelObjectUL2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> vectoritkStatisticsLabelObjectUL2

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type
        v: std::vector< itkStatisticsLabelObjectUL2_Pointer,std::allocator< itkStatisticsLabelObjectUL2_Pointer > > const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> vectoritkStatisticsLabelObjectUL2

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::vector< itkStatisticsLabelObjectUL2_Pointer,std::allocator< itkStatisticsLabelObjectUL2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL2_Pointer >::difference_type
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_empty(self)

    def size(self):
        r"""size(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::vector< itkStatisticsLabelObjectUL2_Pointer > &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_begin(self)

    def end(self):
        r"""end(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::allocator_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator

        erase(self, first, last) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator

        Parameters
        ----------
        first: std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator
        last: std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> vectoritkStatisticsLabelObjectUL2
        __init__(self, other) -> vectoritkStatisticsLabelObjectUL2

        Parameters
        ----------
        other: std::vector< itkStatisticsLabelObjectUL2_Pointer > const &

        __init__(self, size) -> vectoritkStatisticsLabelObjectUL2

        Parameters
        ----------
        size: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type

        __init__(self, size, value) -> vectoritkStatisticsLabelObjectUL2

        Parameters
        ----------
        size: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type
        value: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_swiginit(self, _itkStatisticsLabelObjectPython.new_vectoritkStatisticsLabelObjectUL2(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_push_back(self, x)

    def front(self):
        r"""front(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_front(self)

    def back(self):
        r"""back(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::vector< itkStatisticsLabelObjectUL2_Pointer >::iterator
        n: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type
        x: std::vector< itkStatisticsLabelObjectUL2_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_insert(self, *args)

    def reserve(self, n):
        r"""
        reserve(self, n)

        Parameters
        ----------
        n: std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_reserve(self, n)

    def capacity(self):
        r"""capacity(self) -> std::vector< itkStatisticsLabelObjectUL2_Pointer >::size_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_capacity(self)
    __swig_destroy__ = _itkStatisticsLabelObjectPython.delete_vectoritkStatisticsLabelObjectUL2

# Register vectoritkStatisticsLabelObjectUL2 in _itkStatisticsLabelObjectPython:
_itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL2_swigregister(vectoritkStatisticsLabelObjectUL2)
class mapitkStatisticsLabelObjectUL3(collections.abc.MutableMapping if _swig_python_version_info >= (3, 3) else collections.MutableMapping):
    r"""Proxy of C++ std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::size_type"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___len__(self)
    def __iter__(self):
        return self.key_iterator()
    def iterkeys(self):
        return self.key_iterator()
    def itervalues(self):
        return self.value_iterator()
    def iteritems(self):
        return self.iterator()

    def __getitem__(self, key):
        r"""
        __getitem__(self, key) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::mapped_type const &

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___getitem__(self, key)

    def __delitem__(self, key):
        r"""
        __delitem__(self, key)

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___delitem__(self, key)

    def has_key(self, key):
        r"""
        has_key(self, key) -> bool

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_has_key(self, key)

    def keys(self):
        r"""keys(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_keys(self)

    def values(self):
        r"""values(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_values(self)

    def items(self):
        r"""items(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_items(self)

    def __contains__(self, key):
        r"""
        __contains__(self, key) -> bool

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___contains__(self, key)

    def key_iterator(self):
        r"""key_iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_key_iterator(self)

    def value_iterator(self):
        r"""value_iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_value_iterator(self)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, key)

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        __setitem__(self, key, x)

        Parameters
        ----------
        key: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &
        x: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::mapped_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3___setitem__(self, *args)

    def asdict(self):
        r"""asdict(self) -> PyObject *"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_asdict(self)

    def __init__(self, *args):
        r"""
        __init__(self, other) -> mapitkStatisticsLabelObjectUL3

        Parameters
        ----------
        other: std::less< unsigned long > const &

        __init__(self) -> mapitkStatisticsLabelObjectUL3
        __init__(self, other) -> mapitkStatisticsLabelObjectUL3

        Parameters
        ----------
        other: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > > const &

        """
        _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_swiginit(self, _itkStatisticsLabelObjectPython.new_mapitkStatisticsLabelObjectUL3(*args))

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_empty(self)

    def size(self):
        r"""size(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::size_type"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > > &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_begin(self)

    def end(self):
        r"""end(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::allocator_type"""
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_get_allocator(self)

    def count(self, x):
        r"""
        count(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::size_type

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_count(self, x)

    def erase(self, *args):
        r"""
        erase(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::size_type

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        erase(self, position)

        Parameters
        ----------
        position: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator

        erase(self, first, last)

        Parameters
        ----------
        first: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator
        last: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_erase(self, *args)

    def find(self, x):
        r"""
        find(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_find(self, x)

    def lower_bound(self, x):
        r"""
        lower_bound(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_lower_bound(self, x)

    def upper_bound(self, x):
        r"""
        upper_bound(self, x) -> std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::iterator

        Parameters
        ----------
        x: std::map< unsigned long,itkStatisticsLabelObjectUL3_Pointer,std::less< unsigned long > >::key_type const &

        """
        return _itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_upper_bound(self, x)
    __swig_destroy__ = _itkStatisticsLabelObjectPython.delete_mapitkStatisticsLabelObjectUL3

# Register mapitkStatisticsLabelObjectUL3 in _itkStatisticsLabelObjectPython:
_itkStatisticsLabelObjectPython.mapitkStatisticsLabelObjectUL3_swigregister(mapitkStatisticsLabelObjectUL3)
class vectoritkStatisticsLabelObjectUL3(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::vector< itkStatisticsLabelObjectUL3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> vectoritkStatisticsLabelObjectUL3

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type
        v: std::vector< itkStatisticsLabelObjectUL3_Pointer,std::allocator< itkStatisticsLabelObjectUL3_Pointer > > const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type
        j: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> vectoritkStatisticsLabelObjectUL3

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::vector< itkStatisticsLabelObjectUL3_Pointer,std::allocator< itkStatisticsLabelObjectUL3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::vector< itkStatisticsLabelObjectUL3_Pointer >::difference_type
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_empty(self)

    def size(self):
        r"""size(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::vector< itkStatisticsLabelObjectUL3_Pointer > &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_begin(self)

    def end(self):
        r"""end(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::reverse_iterator"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::allocator_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator

        erase(self, first, last) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator

        Parameters
        ----------
        first: std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator
        last: std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> vectoritkStatisticsLabelObjectUL3
        __init__(self, other) -> vectoritkStatisticsLabelObjectUL3

        Parameters
        ----------
        other: std::vector< itkStatisticsLabelObjectUL3_Pointer > const &

        __init__(self, size) -> vectoritkStatisticsLabelObjectUL3

        Parameters
        ----------
        size: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type

        __init__(self, size, value) -> vectoritkStatisticsLabelObjectUL3

        Parameters
        ----------
        size: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type
        value: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_swiginit(self, _itkStatisticsLabelObjectPython.new_vectoritkStatisticsLabelObjectUL3(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_push_back(self, x)

    def front(self):
        r"""front(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_front(self)

    def back(self):
        r"""back(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::vector< itkStatisticsLabelObjectUL3_Pointer >::iterator
        n: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type
        x: std::vector< itkStatisticsLabelObjectUL3_Pointer >::value_type const &

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_insert(self, *args)

    def reserve(self, n):
        r"""
        reserve(self, n)

        Parameters
        ----------
        n: std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type

        """
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_reserve(self, n)

    def capacity(self):
        r"""capacity(self) -> std::vector< itkStatisticsLabelObjectUL3_Pointer >::size_type"""
        return _itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_capacity(self)
    __swig_destroy__ = _itkStatisticsLabelObjectPython.delete_vectoritkStatisticsLabelObjectUL3

# Register vectoritkStatisticsLabelObjectUL3 in _itkStatisticsLabelObjectPython:
_itkStatisticsLabelObjectPython.vectoritkStatisticsLabelObjectUL3_swigregister(vectoritkStatisticsLabelObjectUL3)

def itkStatisticsLabelObjectUL2_New():
    return itkStatisticsLabelObjectUL2.New()

class itkStatisticsLabelObjectUL2(itk.itkShapeLabelObjectPython.itkShapeLabelObjectUL2):
    r"""Proxy of C++ itkStatisticsLabelObjectUL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkStatisticsLabelObjectUL2_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkStatisticsLabelObjectUL2_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_Clone(self)

    @staticmethod
    def GetAttributeFromName(s):
        r"""
        GetAttributeFromName(s) -> unsigned int

        Parameters
        ----------
        s: std::string const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetAttributeFromName(s)

    @staticmethod
    def GetNameFromAttribute(a):
        r"""
        GetNameFromAttribute(a) -> std::string

        Parameters
        ----------
        a: unsigned int const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetNameFromAttribute(a)

    def GetMinimum(self):
        r"""GetMinimum(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetMinimum(self)

    def SetMinimum(self, v):
        r"""
        SetMinimum(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetMinimum(self, v)

    def GetMaximum(self):
        r"""GetMaximum(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetMaximum(self)

    def SetMaximum(self, v):
        r"""
        SetMaximum(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetMaximum(self, v)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetMean(self)

    def SetMean(self, v):
        r"""
        SetMean(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetMean(self, v)

    def GetSum(self):
        r"""GetSum(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetSum(self)

    def SetSum(self, v):
        r"""
        SetSum(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetSum(self, v)

    def GetStandardDeviation(self):
        r"""GetStandardDeviation(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetStandardDeviation(self)

    def SetStandardDeviation(self, v):
        r"""
        SetStandardDeviation(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetStandardDeviation(self, v)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetVariance(self)

    def SetVariance(self, v):
        r"""
        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetVariance(self, v)

    def GetMedian(self):
        r"""GetMedian(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetMedian(self)

    def SetMedian(self, v):
        r"""
        SetMedian(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetMedian(self, v)

    def GetMaximumIndex(self):
        r"""GetMaximumIndex(self) -> itkIndex2"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetMaximumIndex(self)

    def SetMaximumIndex(self, v):
        r"""
        SetMaximumIndex(self, v)

        Parameters
        ----------
        v: itkIndex2 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetMaximumIndex(self, v)

    def GetMinimumIndex(self):
        r"""GetMinimumIndex(self) -> itkIndex2"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetMinimumIndex(self)

    def SetMinimumIndex(self, v):
        r"""
        SetMinimumIndex(self, v)

        Parameters
        ----------
        v: itkIndex2 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetMinimumIndex(self, v)

    def GetCenterOfGravity(self):
        r"""GetCenterOfGravity(self) -> itkPointD2"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetCenterOfGravity(self)

    def SetCenterOfGravity(self, v):
        r"""
        SetCenterOfGravity(self, v)

        Parameters
        ----------
        v: itkPointD2 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetCenterOfGravity(self, v)

    def GetWeightedPrincipalMoments(self):
        r"""GetWeightedPrincipalMoments(self) -> itkVectorD2"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetWeightedPrincipalMoments(self)

    def SetWeightedPrincipalMoments(self, v):
        r"""
        SetWeightedPrincipalMoments(self, v)

        Parameters
        ----------
        v: itkVectorD2 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetWeightedPrincipalMoments(self, v)

    def GetWeightedPrincipalAxes(self):
        r"""GetWeightedPrincipalAxes(self) -> itkMatrixD22"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetWeightedPrincipalAxes(self)

    def SetWeightedPrincipalAxes(self, v):
        r"""
        SetWeightedPrincipalAxes(self, v)

        Parameters
        ----------
        v: itkMatrixD22 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetWeightedPrincipalAxes(self, v)

    def GetSkewness(self):
        r"""GetSkewness(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetSkewness(self)

    def SetSkewness(self, v):
        r"""
        SetSkewness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetSkewness(self, v)

    def GetKurtosis(self):
        r"""GetKurtosis(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetKurtosis(self)

    def SetKurtosis(self, v):
        r"""
        SetKurtosis(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetKurtosis(self, v)

    def GetWeightedElongation(self):
        r"""GetWeightedElongation(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetWeightedElongation(self)

    def SetWeightedElongation(self, v):
        r"""
        SetWeightedElongation(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetWeightedElongation(self, v)

    def GetHistogram(self):
        r"""GetHistogram(self) -> itkHistogramD"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetHistogram(self)

    def SetHistogram(self, v):
        r"""
        SetHistogram(self, v)

        Parameters
        ----------
        v: itkHistogramD const *

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetHistogram(self, v)

    def GetWeightedFlatness(self):
        r"""GetWeightedFlatness(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetWeightedFlatness(self)

    def SetWeightedFlatness(self, v):
        r"""
        SetWeightedFlatness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_SetWeightedFlatness(self, v)

    def GetWeightedPrincipalAxesToPhysicalAxesTransform(self):
        r"""GetWeightedPrincipalAxesToPhysicalAxesTransform(self) -> itkAffineTransformD2_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetWeightedPrincipalAxesToPhysicalAxesTransform(self)

    def GetPhysicalAxesToWeightedPrincipalAxesTransform(self):
        r"""GetPhysicalAxesToWeightedPrincipalAxesTransform(self) -> itkAffineTransformD2_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_GetPhysicalAxesToWeightedPrincipalAxesTransform(self)
    __swig_destroy__ = _itkStatisticsLabelObjectPython.delete_itkStatisticsLabelObjectUL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkStatisticsLabelObjectUL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkStatisticsLabelObjectUL2

        Create a new object of the class itkStatisticsLabelObjectUL2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkStatisticsLabelObjectUL2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkStatisticsLabelObjectUL2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkStatisticsLabelObjectUL2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkStatisticsLabelObjectUL2 in _itkStatisticsLabelObjectPython:
_itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL2_swigregister(itkStatisticsLabelObjectUL2)

def itkStatisticsLabelObjectUL3_New():
    return itkStatisticsLabelObjectUL3.New()

class itkStatisticsLabelObjectUL3(itk.itkShapeLabelObjectPython.itkShapeLabelObjectUL3):
    r"""Proxy of C++ itkStatisticsLabelObjectUL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkStatisticsLabelObjectUL3_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkStatisticsLabelObjectUL3_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_Clone(self)

    @staticmethod
    def GetAttributeFromName(s):
        r"""
        GetAttributeFromName(s) -> unsigned int

        Parameters
        ----------
        s: std::string const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetAttributeFromName(s)

    @staticmethod
    def GetNameFromAttribute(a):
        r"""
        GetNameFromAttribute(a) -> std::string

        Parameters
        ----------
        a: unsigned int const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetNameFromAttribute(a)

    def GetMinimum(self):
        r"""GetMinimum(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetMinimum(self)

    def SetMinimum(self, v):
        r"""
        SetMinimum(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetMinimum(self, v)

    def GetMaximum(self):
        r"""GetMaximum(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetMaximum(self)

    def SetMaximum(self, v):
        r"""
        SetMaximum(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetMaximum(self, v)

    def GetMean(self):
        r"""GetMean(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetMean(self)

    def SetMean(self, v):
        r"""
        SetMean(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetMean(self, v)

    def GetSum(self):
        r"""GetSum(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetSum(self)

    def SetSum(self, v):
        r"""
        SetSum(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetSum(self, v)

    def GetStandardDeviation(self):
        r"""GetStandardDeviation(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetStandardDeviation(self)

    def SetStandardDeviation(self, v):
        r"""
        SetStandardDeviation(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetStandardDeviation(self, v)

    def GetVariance(self):
        r"""GetVariance(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetVariance(self)

    def SetVariance(self, v):
        r"""
        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetVariance(self, v)

    def GetMedian(self):
        r"""GetMedian(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetMedian(self)

    def SetMedian(self, v):
        r"""
        SetMedian(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetMedian(self, v)

    def GetMaximumIndex(self):
        r"""GetMaximumIndex(self) -> itkIndex3"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetMaximumIndex(self)

    def SetMaximumIndex(self, v):
        r"""
        SetMaximumIndex(self, v)

        Parameters
        ----------
        v: itkIndex3 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetMaximumIndex(self, v)

    def GetMinimumIndex(self):
        r"""GetMinimumIndex(self) -> itkIndex3"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetMinimumIndex(self)

    def SetMinimumIndex(self, v):
        r"""
        SetMinimumIndex(self, v)

        Parameters
        ----------
        v: itkIndex3 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetMinimumIndex(self, v)

    def GetCenterOfGravity(self):
        r"""GetCenterOfGravity(self) -> itkPointD3"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetCenterOfGravity(self)

    def SetCenterOfGravity(self, v):
        r"""
        SetCenterOfGravity(self, v)

        Parameters
        ----------
        v: itkPointD3 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetCenterOfGravity(self, v)

    def GetWeightedPrincipalMoments(self):
        r"""GetWeightedPrincipalMoments(self) -> itkVectorD3"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetWeightedPrincipalMoments(self)

    def SetWeightedPrincipalMoments(self, v):
        r"""
        SetWeightedPrincipalMoments(self, v)

        Parameters
        ----------
        v: itkVectorD3 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetWeightedPrincipalMoments(self, v)

    def GetWeightedPrincipalAxes(self):
        r"""GetWeightedPrincipalAxes(self) -> itkMatrixD33"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetWeightedPrincipalAxes(self)

    def SetWeightedPrincipalAxes(self, v):
        r"""
        SetWeightedPrincipalAxes(self, v)

        Parameters
        ----------
        v: itkMatrixD33 const &

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetWeightedPrincipalAxes(self, v)

    def GetSkewness(self):
        r"""GetSkewness(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetSkewness(self)

    def SetSkewness(self, v):
        r"""
        SetSkewness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetSkewness(self, v)

    def GetKurtosis(self):
        r"""GetKurtosis(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetKurtosis(self)

    def SetKurtosis(self, v):
        r"""
        SetKurtosis(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetKurtosis(self, v)

    def GetWeightedElongation(self):
        r"""GetWeightedElongation(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetWeightedElongation(self)

    def SetWeightedElongation(self, v):
        r"""
        SetWeightedElongation(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetWeightedElongation(self, v)

    def GetHistogram(self):
        r"""GetHistogram(self) -> itkHistogramD"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetHistogram(self)

    def SetHistogram(self, v):
        r"""
        SetHistogram(self, v)

        Parameters
        ----------
        v: itkHistogramD const *

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetHistogram(self, v)

    def GetWeightedFlatness(self):
        r"""GetWeightedFlatness(self) -> double const &"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetWeightedFlatness(self)

    def SetWeightedFlatness(self, v):
        r"""
        SetWeightedFlatness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_SetWeightedFlatness(self, v)

    def GetWeightedPrincipalAxesToPhysicalAxesTransform(self):
        r"""GetWeightedPrincipalAxesToPhysicalAxesTransform(self) -> itkAffineTransformD3_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetWeightedPrincipalAxesToPhysicalAxesTransform(self)

    def GetPhysicalAxesToWeightedPrincipalAxesTransform(self):
        r"""GetPhysicalAxesToWeightedPrincipalAxesTransform(self) -> itkAffineTransformD3_Pointer"""
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_GetPhysicalAxesToWeightedPrincipalAxesTransform(self)
    __swig_destroy__ = _itkStatisticsLabelObjectPython.delete_itkStatisticsLabelObjectUL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkStatisticsLabelObjectUL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkStatisticsLabelObjectUL3

        Create a new object of the class itkStatisticsLabelObjectUL3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkStatisticsLabelObjectUL3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkStatisticsLabelObjectUL3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkStatisticsLabelObjectUL3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkStatisticsLabelObjectUL3 in _itkStatisticsLabelObjectPython:
_itkStatisticsLabelObjectPython.itkStatisticsLabelObjectUL3_swigregister(itkStatisticsLabelObjectUL3)

